# Lazurite

Unofficial shader development tool for Minecraft: Bedrock Edition with RenderDragon graphics engine, which focuses on intuitive use and powerful features.

## Installation

Lazurite requires to have Python 3.10+ installed, but 3.12 is recommended.

Official python installation page: <https://www.python.org/downloads/>

After installing python, you can install lazurite package from pypi repository, with a command

```sh
pip install lazurite
```

or

```sh
python -m pip install lazurite
```

## Next steps

Read the documentation here <https://veka0.github.io/lazurite>
